@@ -1,10 +1,10 @@
 package WebService::PayPal::PaymentsAdvanced::Error::Authentication;
-$WebService::PayPal::PaymentsAdvanced::Error::Authentication::VERSION = '0.000002';
+$WebService::PayPal::PaymentsAdvanced::Error::Authentication::VERSION = '0.000003';
 use Moo;
 
 extends 'Throwable::Error';
 
-with 'WebService::PayPal::PaymentsAdvanced::Role::Error::HasParams';
+with 'WebService::PayPal::PaymentsAdvanced::Role::HasParams';
 
 1;
 
@@ -22,7 +22,7 @@ WebService::PayPal::PaymentsAdvanced::Error::Authentication - A Payments Advance
 
 =head1 VERSION
 
-version 0.000002
+version 0.000003
 
 =head1 SYNOPSIS
 
