@@ -1,8 +1,8 @@
 package WebService::PayPal::PaymentsAdvanced::Error::Generic;
-$WebService::PayPal::PaymentsAdvanced::Error::Generic::VERSION = '0.000002';
+$WebService::PayPal::PaymentsAdvanced::Error::Generic::VERSION = '0.000003';
 use Moo;
 
-with 'WebService::PayPal::PaymentsAdvanced::Role::Error::HasParams';
+with 'WebService::PayPal::PaymentsAdvanced::Role::HasParams';
 
 extends 'Throwable::Error';
 
@@ -22,7 +22,7 @@ WebService::PayPal::PaymentsAdvanced::Error::Generic - A generic error
 
 =head1 VERSION
 
-version 0.000002
+version 0.000003
 
 =head1 SYNOPSIS
 
