@@ -1,5 +1,5 @@
 package WebService::PayPal::PaymentsAdvanced::Error::IPVerification;
-$WebService::PayPal::PaymentsAdvanced::Error::IPVerification::VERSION = '0.000002';
+$WebService::PayPal::PaymentsAdvanced::Error::IPVerification::VERSION = '0.000003';
 use Moo;
 
 extends 'Throwable::Error';
@@ -12,7 +12,7 @@ has ip_address => (
     required => 1,
 );
 
-with 'WebService::PayPal::PaymentsAdvanced::Role::Error::HasParams';
+with 'WebService::PayPal::PaymentsAdvanced::Role::HasParams';
 
 1;
 
@@ -30,7 +30,7 @@ WebService::PayPal::PaymentsAdvanced::Error::IPVerification - A Payments Advance
 
 =head1 VERSION
 
-version 0.000002
+version 0.000003
 
 =head1 SYNOPSIS
 
